@@ -1366,12 +1366,47 @@ static gboolean src_crosswire	    	= FALSE;
     {
     }
 
-    else
+    else*/
     if (config->key && 
 	strcmp (config->key, MAGNIFIER_ACTIVE_SCHEMA MAGNIFIER_TARGET) == 0)
     {
+	if (config->newvalue &&
+	    config->type == CFGT_STRING)
+	{
+	    gchar *target = (gchar*)config->newvalue;
+
+	    if (src_use_magnifier)
+	    {
+		gchar *mag_out;
+/*FIXME -lift freeze*/
+/*		if (src_use_speech)
+		{
+		    gchar *tmp;
+		    tmp = g_strdup_printf ("%s %s",
+					   _("magnifier target"),
+					   target);
+		    src_say_message (tmp);
+		    g_free (tmp);
+		}
+*/
+		mag_out = g_strconcat ("<MAGOUT><ZOOMER ID=\"generic_zoomer\" target=\"",
+			    		target,
+					" \"></ZOOMER></MAGOUT>",
+					NULL);
+		if (mag_out)
+		{
+		 /*   fprintf (stderr, "\n%s %d : target %s",
+					__FILE__,
+					__LINE__,
+					target);
+		 */ src_magnifier_send (mag_out);
+		    g_free (mag_out);
+		    mag_out = NULL;
+		}
+	    }
+	}
     }
-    else*/
+    else
       if (config->key &&
 	strcmp (config->key, MAGNIFIER_ACTIVE_SCHEMA MAGNIFIER_SOURCE) == 0)
     {
