@@ -305,7 +305,8 @@ typedef enum _SRObjectRole
     SR_ROLE_TABLE_ROW_HEADER ,
 /*    SR_ROLE_TEAROFF_MENU_ITEM ,*/
     /* An object that presents text to the user */
-    SR_ROLE_TEXT,
+    SR_ROLE_TEXT_ML,
+    SR_ROLE_TEXT_SL,
     /*
      * A specialized push button that can be checked or unchecked, but does
      * not procide a separate indicator for the current state.
@@ -345,6 +346,7 @@ typedef enum _SRObjectRole
 	SR_ROLE_TABLE_LINE,
 	SR_ROLE_TABLE_COLUMNS_HEADER,
 	SR_ROLE_TITLE_BAR,
+	SR_ROLE_EDITBAR,
     
     /* not a valid role, used for finding end of enumeration. */
     SR_ROLE_LAST_DEFINED
@@ -406,6 +408,7 @@ gboolean sro_get_state 		(const SRObject *obj, SRState *state, SRLong index);
 gboolean sro_get_relation	(const SRObject *obj, SRRelation *relation, SRLong index);
 gboolean sro_get_role_name	(const SRObject *obj, gchar **role_name,SRLong index);
 gboolean sro_get_name 		(const SRObject *obj, gchar **name, SRLong index);
+gboolean sro_get_header 	(const SRObject *obj, gchar **header, SRLong index);
 gboolean sro_get_description 	(const SRObject *obj, gchar **description, SRLong index);
 gboolean sro_get_parent 	(const SRObject *obj, SRObject **parent);
 gboolean sro_get_index_in_parent(const SRObject *obj, guint32 *index);
@@ -421,6 +424,7 @@ gboolean sro_get_shortcut	(SRObject *obj, gchar **shortcut, SRLong index);
 gboolean sro_get_accelerator	(SRObject *obj, gchar **accelerator, SRLong index);
 gboolean sro_get_objs_for_relation(SRObject *obj, SRRelation type,
 					SRObject ***targets, SRLong index);
+gboolean sro_manages_descendants(SRObject *obj);
 gboolean sro_get_index_in_group (SRObject *obj, SRLong *index, SRLong index_obj);
 
 gboolean sro_action_get_count 	 	(SRObject *obj, SRLong *count, SRLong index);
@@ -522,6 +526,7 @@ gboolean sro_get_next_image (SRObject *obj, SRObject **next, SRNavigationMode mo
 gboolean sro_get_next_attributes (SRObject *obj, gchar *attr, SRObject **next, SRNavigationMode mode);
 
 gboolean sro_get_sros_from_rectangle (SRRectangle *area, GArray **array, gboolean intersect);
+gboolean sro_alert_get_info (SRObject *obj, gchar **title, gchar **text, gchar **button);
 
 #ifdef SRL_DEBUG
 void SR_freeString 	(gchar *str);
